@@ -18,9 +18,9 @@
 #' \code{\link{forest.meta}} function.
 #'
 #' @param x An object of class \code{orbbound}.
-#' @param comb.fixed A logical indicating whether sensitivity analysis
+#' @param fixed A logical indicating whether sensitivity analysis
 #'   for fixed effect model should be plotted.
-#' @param comb.random A logical indicating whether sensitivity
+#' @param random A logical indicating whether sensitivity
 #'   analysis for random effects model should be plotted.
 #' @param text.fixed A character string used in the plot to label
 #'   subgroup with results for fixed effect model.
@@ -68,8 +68,8 @@
 
 
 forest.orbbound <- function(x,
-                            comb.fixed = x$x$comb.fixed,
-                            comb.random = x$x$comb.random,
+                            fixed = x$x$fixed,
+                            random = x$x$random,
                             text.fixed = "FE model",
                             text.random = "RE model",
                             smlab = NULL,
@@ -79,7 +79,7 @@ forest.orbbound <- function(x,
                             digits = max(3, .Options$digits - 3),
                             ...) {
   
-  meta:::chkclass(x, "orbbound")
+  chkclass(x, "orbbound")
   
   k <- x$x$k
   sm <- x$x$sm
@@ -88,9 +88,9 @@ forest.orbbound <- function(x,
   cl <- class(x)[1]
   addargs <- names(list(...))
   ##
-  fun <- "print.summary.limitmeta"
+  fun <- "forest.orbbound"
   ##
-  meta:::warnarg("logscale", addargs, fun, otherarg = "backtransf")
+  warnarg("logscale", addargs, fun, otherarg = "backtransf")
   ##
   if (is.null(backtransf))
     if (!is.null(list(...)[["logscale"]]))
@@ -99,11 +99,11 @@ forest.orbbound <- function(x,
       backtransf <- TRUE
   
   
-  if (length(comb.fixed) == 0)
-    comb.fixed <- TRUE
+  if (length(fixed) == 0)
+    fixed <- TRUE
   ##
-  if (length(comb.random) == 0)
-    comb.random <- TRUE
+  if (length(random) == 0)
+    random <- TRUE
   
   
   sm.lab <- sm
@@ -115,11 +115,11 @@ forest.orbbound <- function(x,
       sm.lab <- "proportion"
   }
   else 
-    if (meta:::is.relative.effect(sm))
+    if (is.relative.effect(sm))
       sm.lab <- paste("log", sm, sep = "")
   
   
-  ci.lab <- paste(round(100 * x$x$level.comb, 1), "%-CI", sep = "")
+  ci.lab <- paste(round(100 * x$x$level.ma, 1), "%-CI", sep = "")
   
   
   TE.fixed   <- x$fixed$TE
@@ -129,38 +129,38 @@ forest.orbbound <- function(x,
   seTE.random <- rep(x$random$seTE, length(TE.random))
   
   
-  if (comb.fixed & comb.random) {
+  if (fixed & random) {
     TE <- c(TE.fixed, TE.random)
     seTE <- c(seTE.fixed, seTE.random)
     FEvsRE <- c(rep(text.fixed, length(TE.fixed)),
                 rep(text.random, length(TE.random)))
   }
-  if (comb.fixed & !comb.random) {
+  if (fixed & !random) {
     TE <- TE.fixed
     seTE <- seTE.fixed
     if (is.null(smlab))
       smlab <- "Fixed effect model"
   }
-  if (!comb.fixed & comb.random) {
+  if (!fixed & random) {
     TE <- TE.random
     seTE <- seTE.random
     if (is.null(smlab))
       smlab <- "Random effects model"
   }
-  if (!comb.fixed & !comb.random) {
-    warning("No forest plot generated as both arguments 'comb.fixed' and 'comb.random' are FALSE")
+  if (!fixed & !random) {
+    warning("No forest plot generated as both arguments 'fixed' and 'random' are FALSE")
     return(invisible(NULL))
   }
   
   
-  if (comb.fixed & comb.random)
+  if (fixed & random)
     m1 <- metagen(TE, seTE, sm = sm.lab,
                   byvar = FEvsRE, print.byvar = FALSE,
                   warn = FALSE, method.tau.ci = "")
   else
     m1 <- metagen(TE, seTE, sm = sm.lab, warn = FALSE, method.tau.ci = "")
   ##
-  if (comb.fixed & comb.random) {
+  if (fixed & random) {
     m1$studlab <- c(x$k.suspect, x$k.suspect)
     m1$maxbias <- c(x$maxbias, x$maxbias)
     m1$npft.ma <- c(1 / mean(1 / x$x$n), 1 / mean(1 / x$x$n))
@@ -173,13 +173,13 @@ forest.orbbound <- function(x,
   
   
   if (backtransf)
-    m1$maxbias <- meta:::backtransf(m1$maxbias, sm, "mean",
+    m1$maxbias <- backtransf(m1$maxbias, sm, "mean",
                                     m1$npft.ma, warn = FALSE)
   ##
   m1$maxbias <- format(round(m1$maxbias, digits))
   
   forest(m1,
-         comb.fixed = FALSE, comb.random = FALSE,
+         fixed = FALSE, random = FALSE,
          hetstat = FALSE,
          leftcols = leftcols,
          leftlabs = leftlabs,
